/*
Copyright 2021 The Crossplane Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1

import (
	"context"
	"time"

	v1 "github.com/crossplane/crossplane/apis/pkg/v1"
	scheme "github.com/crossplane/crossplane/internal/client/clientset/versioned/scheme"
	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// ProviderRevisionsGetter has a method to return a ProviderRevisionInterface.
// A group's client should implement this interface.
type ProviderRevisionsGetter interface {
	ProviderRevisions() ProviderRevisionInterface
}

// ProviderRevisionInterface has methods to work with ProviderRevision resources.
type ProviderRevisionInterface interface {
	Create(ctx context.Context, providerRevision *v1.ProviderRevision, opts metav1.CreateOptions) (*v1.ProviderRevision, error)
	Update(ctx context.Context, providerRevision *v1.ProviderRevision, opts metav1.UpdateOptions) (*v1.ProviderRevision, error)
	UpdateStatus(ctx context.Context, providerRevision *v1.ProviderRevision, opts metav1.UpdateOptions) (*v1.ProviderRevision, error)
	Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
	Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.ProviderRevision, error)
	List(ctx context.Context, opts metav1.ListOptions) (*v1.ProviderRevisionList, error)
	Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.ProviderRevision, err error)
	ProviderRevisionExpansion
}

// providerRevisions implements ProviderRevisionInterface
type providerRevisions struct {
	client rest.Interface
}

// newProviderRevisions returns a ProviderRevisions
func newProviderRevisions(c *PkgV1Client) *providerRevisions {
	return &providerRevisions{
		client: c.RESTClient(),
	}
}

// Get takes name of the providerRevision, and returns the corresponding providerRevision object, and an error if there is any.
func (c *providerRevisions) Get(ctx context.Context, name string, options metav1.GetOptions) (result *v1.ProviderRevision, err error) {
	result = &v1.ProviderRevision{}
	err = c.client.Get().
		Resource("providerrevisions").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do(ctx).
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of ProviderRevisions that match those selectors.
func (c *providerRevisions) List(ctx context.Context, opts metav1.ListOptions) (result *v1.ProviderRevisionList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1.ProviderRevisionList{}
	err = c.client.Get().
		Resource("providerrevisions").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do(ctx).
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested providerRevisions.
func (c *providerRevisions) Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Resource("providerrevisions").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch(ctx)
}

// Create takes the representation of a providerRevision and creates it.  Returns the server's representation of the providerRevision, and an error, if there is any.
func (c *providerRevisions) Create(ctx context.Context, providerRevision *v1.ProviderRevision, opts metav1.CreateOptions) (result *v1.ProviderRevision, err error) {
	result = &v1.ProviderRevision{}
	err = c.client.Post().
		Resource("providerrevisions").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(providerRevision).
		Do(ctx).
		Into(result)
	return
}

// Update takes the representation of a providerRevision and updates it. Returns the server's representation of the providerRevision, and an error, if there is any.
func (c *providerRevisions) Update(ctx context.Context, providerRevision *v1.ProviderRevision, opts metav1.UpdateOptions) (result *v1.ProviderRevision, err error) {
	result = &v1.ProviderRevision{}
	err = c.client.Put().
		Resource("providerrevisions").
		Name(providerRevision.Name).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(providerRevision).
		Do(ctx).
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (c *providerRevisions) UpdateStatus(ctx context.Context, providerRevision *v1.ProviderRevision, opts metav1.UpdateOptions) (result *v1.ProviderRevision, err error) {
	result = &v1.ProviderRevision{}
	err = c.client.Put().
		Resource("providerrevisions").
		Name(providerRevision.Name).
		SubResource("status").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(providerRevision).
		Do(ctx).
		Into(result)
	return
}

// Delete takes name of the providerRevision and deletes it. Returns an error if one occurs.
func (c *providerRevisions) Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error {
	return c.client.Delete().
		Resource("providerrevisions").
		Name(name).
		Body(&opts).
		Do(ctx).
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *providerRevisions) DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error {
	var timeout time.Duration
	if listOpts.TimeoutSeconds != nil {
		timeout = time.Duration(*listOpts.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Resource("providerrevisions").
		VersionedParams(&listOpts, scheme.ParameterCodec).
		Timeout(timeout).
		Body(&opts).
		Do(ctx).
		Error()
}

// Patch applies the patch and returns the patched providerRevision.
func (c *providerRevisions) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.ProviderRevision, err error) {
	result = &v1.ProviderRevision{}
	err = c.client.Patch(pt).
		Resource("providerrevisions").
		Name(name).
		SubResource(subresources...).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(data).
		Do(ctx).
		Into(result)
	return
}
